diff --git a/test/ServerComparison.FunctionalTests/HelloWorldTest.cs b/test/ServerComparison.FunctionalTests/HelloWorldTest.cs
index aacc39dbdb..2c39e051df 100644
--- a/test/ServerComparison.FunctionalTests/HelloWorldTest.cs
+++ b/test/ServerComparison.FunctionalTests/HelloWorldTest.cs
@@ -5,8 +5,8 @@ using System;
using System.IO;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Server.Testing;
-using Microsoft.AspNet.Testing.xunit;
+using Microsoft.AspNetCore.Server.Testing;
+using Microsoft.AspNetCore.Testing.xunit;
using Microsoft.Extensions.Logging;
using Xunit;
using Xunit.Sdk;
diff --git a/test/ServerComparison.FunctionalTests/NtlmAuthentationTest.cs b/test/ServerComparison.FunctionalTests/NtlmAuthentationTest.cs
index 564c686ba2..26c2d2d97a 100644
--- a/test/ServerComparison.FunctionalTests/NtlmAuthentationTest.cs
+++ b/test/ServerComparison.FunctionalTests/NtlmAuthentationTest.cs
@@ -6,8 +6,8 @@ using System.IO;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Server.Testing;
-using Microsoft.AspNet.Testing.xunit;
+using Microsoft.AspNetCore.Server.Testing;
+using Microsoft.AspNetCore.Testing.xunit;
using Microsoft.Extensions.Logging;
using Xunit;
using Xunit.Sdk;
diff --git a/test/ServerComparison.FunctionalTests/ResponseTests.cs b/test/ServerComparison.FunctionalTests/ResponseTests.cs
index 25291d8d09..b02eebffba 100644
--- a/test/ServerComparison.FunctionalTests/ResponseTests.cs
+++ b/test/ServerComparison.FunctionalTests/ResponseTests.cs
@@ -7,8 +7,8 @@ using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
-using Microsoft.AspNet.Server.Testing;
-using Microsoft.AspNet.Testing.xunit;
+using Microsoft.AspNetCore.Server.Testing;
+using Microsoft.AspNetCore.Testing.xunit;
using Microsoft.Extensions.Logging;
using Microsoft.Net.Http.Headers;
using Xunit;
diff --git a/test/ServerComparison.FunctionalTests/project.json b/test/ServerComparison.FunctionalTests/project.json
index e8bf5fd0e7..d202cd9f89 100644
--- a/test/ServerComparison.FunctionalTests/project.json
+++ b/test/ServerComparison.FunctionalTests/project.json
@@ -6,8 +6,8 @@
"test": "xunit.runner.aspnet"
},
"dependencies": {
- "Microsoft.AspNet.Server.IIS": "1.0.0-*",
- "Microsoft.AspNet.Server.Testing": "1.0.0-*",
+ "Microsoft.AspNetCore.Server.IIS": "1.0.0-*",
+ "Microsoft.AspNetCore.Server.Testing": "1.0.0-*",
"Microsoft.Extensions.Logging.Console": "1.0.0-*",
"xunit.runner.aspnet": "2.0.0-aspnet-*"
},
diff --git a/test/ServerComparison.TestSites/Program.cs b/test/ServerComparison.TestSites/Program.cs
index f211f127d7..5adfff0d9c 100644
--- a/test/ServerComparison.TestSites/Program.cs
+++ b/test/ServerComparison.TestSites/Program.cs
@@ -1,7 +1,7 @@
-// Copyright (c) .NET Foundation. All rights reserved.
+// Copyright (c) .NET Foundation. All rights reserved.
// Licensed under the Apache License, Version 2.0. See License.txt in the project root for license information.
-using Microsoft.AspNet.Hosting;
+using Microsoft.AspNetCore.Hosting;
namespace ServerComparison.TestSites
{
diff --git a/test/ServerComparison.TestSites/StartupResponses.cs b/test/ServerComparison.TestSites/StartupResponses.cs
index 53e11362b4..ebce640b37 100644
--- a/test/ServerComparison.TestSites/StartupResponses.cs
+++ b/test/ServerComparison.TestSites/StartupResponses.cs
@@ -1,8 +1,8 @@
// Copyright (c) .NET Foundation. All rights reserved.
// Licensed under the Apache License, Version 2.0. See License.txt in the project root for license information.
-using Microsoft.AspNet.Builder;
-using Microsoft.AspNet.Http;
+using Microsoft.AspNetCore.Builder;
+using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Logging;
using Microsoft.Net.Http.Headers;
diff --git a/test/ServerComparison.TestSites/hosting.json b/test/ServerComparison.TestSites/hosting.json
index f8ef14574d..6a93dbafa8 100644
--- a/test/ServerComparison.TestSites/hosting.json
+++ b/test/ServerComparison.TestSites/hosting.json
@@ -1,3 +1,3 @@
-{
- "server": "Microsoft.AspNet.Server.Kestrel"
+{
+ "server": "Microsoft.AspNetCore.Server.Kestrel"
}
diff --git a/test/ServerComparison.TestSites/project.json b/test/ServerComparison.TestSites/project.json
index 47c044c6b7..02899f85ee 100644
--- a/test/ServerComparison.TestSites/project.json
+++ b/test/ServerComparison.TestSites/project.json
@@ -2,10 +2,10 @@
"version": "1.0.0-*",
"dependencies": {
- "Microsoft.AspNet.IISPlatformHandler": "1.0.0-*",
- "Microsoft.AspNet.Server.Kestrel": "1.0.0-*",
- "Microsoft.AspNet.Server.WebListener": "1.0.0-*",
- "Microsoft.AspNet.WebUtilities": "1.0.0-*",
+ "Microsoft.AspNetCore.IISPlatformHandler": "1.0.0-*",
+ "Microsoft.AspNetCore.Server.Kestrel": "1.0.0-*",
+ "Microsoft.AspNetCore.Server.WebListener": "1.0.0-*",
+ "Microsoft.AspNetCore.WebUtilities": "1.0.0-*",
"Microsoft.Extensions.Configuration.Json": "1.0.0-*",
"Microsoft.Extensions.Logging.Console": "1.0.0-*",
"Microsoft.Net.Http.Headers": "1.0.0-*"
diff --git a/test/ServerComparison.TestSites/StartupHelloWorld.cs b/test/ServerComparison.TestSites/StartupHelloWorld.cs
index c1d079342b..b2d386bf3b 100644
--- a/test/ServerComparison.TestSites/StartupHelloWorld.cs
+++ b/test/ServerComparison.TestSites/StartupHelloWorld.cs
@@ -1,15 +1,15 @@
// Copyright (c) .NET Foundation. All rights reserved.
// Licensed under the Apache License, Version 2.0. See License.txt in the project root for license information.
-using Microsoft.AspNet.Builder;
-using Microsoft.AspNet.Http;
+using Microsoft.AspNetCore.Builder;
+using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Logging;
namespace ServerComparison.TestSites
{
///
/// To make runtime to load an environment based startup class, specify the environment by the following ways:
/// 1. Drop a Microsoft.AspNet.Hosting.ini file in the wwwroot folder
/// 2. Add a setting in the ini file named 'ASPNET_ENV' with value of the format 'Startup[EnvironmentName]'. For example: To load a Startup class named
/// 'StartupHelloWorld' the value of the env should be 'HelloWorld' (eg. ASPNET_ENV=HelloWorld). Runtime adds a 'Startup' prefix to this and loads 'StartupHelloWorld'.
/// If no environment name is specified the default startup class loaded is 'Startup'.
@@ -17,7 +17,7 @@ namespace ServerComparison.TestSites
/// 1. Set the environment variable named SET ASPNET_ENV=HelloWorld
/// 2. For selfhost based servers pass in a command line variable named --env with this value. Eg:
/// "commands": {
- /// "web": "Microsoft.AspNet.Hosting --server Microsoft.AspNet.Server.WebListener --server.urls http://localhost:5002 --ASPNET_ENV HelloWorld",
+ /// "web": "Microsoft.AspNetCore.Hosting --server Microsoft.AspNetCore.Server.WebListener --server.urls http://localhost:5002 --ASPNET_ENV HelloWorld",
/// },
///
public class StartupHelloWorld
@@ -1,15 +1,15 @@
///
/// To make runtime to load an environment based startup class, specify the environment by the following ways:
- /// 1. Drop a Microsoft.AspNet.Hosting.ini file in the wwwroot folder
+ /// 1. Drop a Microsoft.AspNetCore.Hosting.ini file in the wwwroot folder
/// 2. Add a setting in the ini file named 'ASPNET_ENV' with value of the format 'Startup[EnvironmentName]'. For example: To load a Startup class named
/// 'StartupHelloWorld' the value of the env should be 'HelloWorld' (eg. ASPNET_ENV=HelloWorld). Runtime adds a 'Startup' prefix to this and loads 'StartupHelloWorld'.
diff --git a/test/ServerComparison.TestSites/StartupNtlmAuthentication.cs b/test/ServerComparison.TestSites/StartupNtlmAuthentication.cs
index d14cbb774c..ed365f47d1 100644
--- a/test/ServerComparison.TestSites/StartupNtlmAuthentication.cs
+++ b/test/ServerComparison.TestSites/StartupNtlmAuthentication.cs
@@ -2,9 +2,9 @@
// Licensed under the Apache License, Version 2.0. See License.txt in the project root for license information.
using System;
-using Microsoft.AspNet.Builder;
-using Microsoft.AspNet.Http;
-using Microsoft.AspNet.Http.Features;
+using Microsoft.AspNetCore.Builder;
+using Microsoft.AspNetCore.Http;
+using Microsoft.AspNetCore.Http.Features;
using Microsoft.Extensions.Logging;
using Microsoft.Net.Http.Server;
@@ -12,7 +12,7 @@ namespace ServerComparison.TestSites
{
///
/// To make runtime to load an environment based startup class, specify the environment by the following ways:
/// 1. Drop a Microsoft.AspNet.Hosting.ini file in the wwwroot folder
/// 2. Add a setting in the ini file named 'ASPNET_ENV' with value of the format 'Startup[EnvironmentName]'. For example: To load a Startup class named
/// 'StartupNtlmAuthentication' the value of the env should be 'NtlmAuthentication' (eg. ASPNET_ENV=NtlmAuthentication). Runtime adds a 'Startup' prefix to this and loads 'StartupNtlmAuthentication'.
/// If no environment name is specified the default startup class loaded is 'Startup'.
@@ -20,7 +20,7 @@ namespace ServerComparison.TestSites
/// 1. Set the environment variable named SET ASPNET_ENV=NtlmAuthentication
/// 2. For selfhost based servers pass in a command line variable named --env with this value. Eg:
/// "commands": {
- /// "web": "Microsoft.AspNet.Hosting --server Microsoft.AspNet.Server.WebListener --server.urls http://localhost:5002 --ASPNET_ENV NtlmAuthentication",
+ /// "web": "Microsoft.AspNetCore.Hosting --server Microsoft.AspNetCore.Server.WebListener --server.urls http://localhost:5002 --ASPNET_ENV NtlmAuthentication",
/// },
///
public class StartupNtlmAuthentication
@@ -81,7 +81,7 @@ namespace ServerComparison.TestSites
if (context.Request.Path.Equals("/Forbidden"))
{
- return context.Authentication.ForbidAsync(Microsoft.AspNet.Http.Authentication.AuthenticationManager.AutomaticScheme);
+ return context.Authentication.ForbidAsync(Microsoft.AspNetCore.Http.Authentication.AuthenticationManager.AutomaticScheme);
}
if (context.Request.Path.Equals("/AutoForbid"))
@@ -12,7 +12,7 @@ namespace ServerComparison.TestSites
///
/// To make runtime to load an environment based startup class, specify the environment by the following ways:
- /// 1. Drop a Microsoft.AspNet.Hosting.ini file in the wwwroot folder
+ /// 1. Drop a Microsoft.AspNetCore.Hosting.ini file in the wwwroot folder
/// 2. Add a setting in the ini file named 'ASPNET_ENV' with value of the format 'Startup[EnvironmentName]'. For example: To load a Startup class named
/// 'StartupNtlmAuthentication' the value of the env should be 'NtlmAuthentication' (eg. ASPNET_ENV=NtlmAuthentication). Runtime adds a 'Startup' prefix to this and loads 'StartupNtlmAuthentication'.